/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console;

import java.awt.Color;
import java.awt.Component;

import javax.swing.ImageIcon;
import javax.swing.JLabel;
import javax.swing.JPanel;

/**
 * The godfather of all panels
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.50
 */
public class DataCrowPanel extends JPanel {

    protected JLabel labelStatus = new JLabel();
    
    private final String title;
    private final ImageIcon icon;
    
    public DataCrowPanel(String title, ImageIcon icon) {
        this.title = title;
        this.icon = icon;
    }
    
    /**
     * Returns the title for displaying purposes
     */
    public String getTitle() {
    	return title;
    }

    /**
     * Returns the icon belonging to this panel
     */
    public ImageIcon getIcon() {
    	return icon;
    }

    /**
     * Updates the statusbar
     * @param text string to put in the status bar
     */
    public void setStatus(String text) {
        labelStatus.setText(text);
    }
    
    /**
     * Applies the background color to the sub panels
     * @param color background color
     */
    public void setBackground(Color color) {
        super.setBackground(color);

        Component[] components = getComponents();
        for (int i = 0; i < components.length; i++) {
            components[i].setBackground(color);
        }            
    }
}
