/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.audiocd;

import java.util.LinkedList;

import javax.swing.JPanel;

import net.sf.dc.console.InternetSearchForm;
import net.sf.dc.console.MainFrame;
import net.sf.dc.console.RecordForm;
import net.sf.dc.core.DataCrow;
import net.sf.dc.core.Repository;
import net.sf.dc.core.modules.DCModules;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.core.objects.Requestor;
import net.sf.dc.core.objects.RequestorCollection;
import net.sf.dc.processes.http.FreeDBAudioCDUpdate;
import net.sf.dc.resources.DCLabels;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.Resources;

/**
 * Dialog for retrieving information from an audio CD in the CD-Rom drive.
 * Uses FreeDB to get the information based on the discid
 * @see net.sf.dc.freedb.Freedb
 * @see net.sf.dc.processes.http.FreeDBAudioCDUpdate
 * 
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class ImportAudioCDDialog extends InternetSearchForm {
	
    public ImportAudioCDDialog(DCObject dco, RecordForm recordForm) {
        super(dco, recordForm);
        setTitle(Resources.getText(DCLabels.lblImportAudioCD));
        //startSearch();
    }
    
    public ImportAudioCDDialog(DCObject dco, Class clazz, int rowNumber) {
        super(dco, clazz, rowNumber);
        setTitle(Resources.getText(DCLabels.lblImportAudioCD));
        //startSearch();
    }
    
    public JPanel getSearchPanel() {
        return null;
    }

    public void setCancelMode() {
        buttonStopSearch.setEnabled(true);
    }    
    
    public void setSearchMode() {
        buttonStopSearch.setEnabled(false);        
    }
    
    /**
     * Saves the selected server name to the settings
     */
    protected void saveSettings() {
    	Settings.setValue(Repository.settings.stFreeDBSearchFormViewSize,
                          getSize());
        Settings.setValue(Repository.settings.stFreeDBServer, 
                          textServer.getText());
    }    
    
    /**
     * Disc ID search
     */
    public void startSearch() {
        setCancelMode();
        saveSettings();
        process = new FreeDBAudioCDUpdate(this, DCModules.getModule(DCModules._AUDIOCD));
        process.setPriority(Thread.MAX_PRIORITY);
        process.start();
    }    
    
    /**
     * Initialize the values for this dialog
     */
    protected void setDefaultValues() {
        setSize(Settings.getValueAsDimension(
                Repository.settings.stFreeDBSearchFormViewSize));          
        textServer.setText(Settings.getValueAsString(Repository.settings.stFreeDBServer));
    }
    
    /**
     * Transfers the selected result to the requestor 
     */
    public void transferRow() {
        DCObject dco = getSelectedData();
        
        if (dco == null) {
            return;
        }

        String sMethod = "addRow";
        
        Object[] params;
        RequestorCollection requestors = new RequestorCollection();
        
        LinkedList ll = new LinkedList();
        ll.add(dco);
        
        params = new Object[] {ll, Boolean.TRUE};
        Requestor request = new Requestor(clazz, sMethod, params);
        requestors.addRequestor(request);
        
        wf.displayResults(new LinkedList(), requestors, true);
        
        DataCrow.mainFrame.setSelectedTab(MainFrame._INSERTTAB);
        
        close();
    }     
}
