/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.audiocd;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Enumeration;
import java.util.LinkedList;
import java.util.Vector;

import javax.swing.JButton;
import javax.swing.JComponent;

import net.sf.dc.console.TableInsertPanel;
import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.dialogs.MessageBox;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.core.modules.DCModules;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.resources.DCLabels;
import net.sf.ext.util.Resources;

/**
 * The insert Audio Track panel. This panel is different from the default panels
 * as this is a child panel of the Audio CD Panel
 * @see net.sf.dc.console.audiocd.InsertAudioCDPanel
 * 
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class InsertAudioTrackPanel extends TableInsertPanel {

    private LinkedList llTracks = new LinkedList();
    
    /**
     * Creates the panel
     */
    public InsertAudioTrackPanel() {
        super(DCModules.getModule(DCModules._AUDIOTRACK),
              Resources.getText(DCLabels.lblNewValues), 
              IconLibrary._icoNew);
    }

    /**
     * Clears the UI table, does not clear the cache of changed values
     */
    public void clearTable() {
        clearTable(false);
    }    
    
    /**
     * Clears the UI table
     * @param cache clear cache as well ?
     */
    public void clearTable(boolean cache) {
    	table.clearTable();
        if (cache) {
        	clearCache();
        }
    }
    
    /**
     * Clears the cache
     */
    public void clearCache() {
        llTracks.clear();
    }
    
    /**
     * Store the newly added children in a hashtable so they can be showed to
     * the user again when the user selects the parent
     */
    public void rememberChildValues(String id) {
        DCObject[] children = getChildren(id);

        for (int i = 0; i < children.length; i++) {
            llTracks.remove(children[i]);
        }
        
        for (int i = 0; i < table.getRowCount(); i++) {
        	DCObject dco = getObjectForSaving(i);
            dco.setUIRowNumber(i + 1);
            dco.setValue(dco.getParentReferenceFieldIndex(), id);
            llTracks.add(dco);
        }
    }
    
    /**
     * Removes children from both the UI table and the cache
     * @param parentID the ID of the parent to which the children belong 
     */
    public void removeChildren(String parentID) {
        DCObject[] children = getChildren(parentID);
        for (int i = 0; i < children.length; i++) {
            llTracks.remove(children[i]);
        }
        clearTable(false);
        
        
        if (table.getRowCount() == 2 && llTracks.size() > 0) {
        	DCObject dco = (DCObject) llTracks.get(0);
            String key = dco.getValue(dco.getParentReferenceFieldIndex()).toString();
            loadChildValues(key);
        }
    }
    
    /**
     * Loads the children from the cache
     * @param parentID the ID of the parent for which the children are loaded
     */
    public void loadChildValues(String parentID) {
        clearTable();
        DCObject[] children = getChildren(parentID);
        LinkedList data = new LinkedList();        
        for (int i = 0; i < children.length; i++ ) {
            children[i].setValue(children[i].getParentReferenceFieldIndex(), 
                                 parentID);
            data.add(children[i]);
        }
        addRow(data, true);
    }    
    
    /**
     * Retrieves the children for a parent
     * @param parentID the ID of the parent for which the children are retrieved
     */
    public DCObject[] getChildren(String parentID) {
        Vector v = new Vector();
        for (int i = 0; i < llTracks.size(); i++) {
            DCObject dco = (DCObject) llTracks.get(i);
            if (dco.getValue(dco.getParentReferenceFieldIndex()).equals(parentID) ) {
                v.add(dco);
            }
        }
        
        DCObject[] objects = new DCObject[v.size()];
        int counter = 0;
        for (Enumeration enum = v.elements(); enum.hasMoreElements(); counter++) {
        	objects[counter] = (DCObject) enum.nextElement();
        }
        return objects;
    }
    
    /**
     * Return extra action buttons
     */
    public JComponent[] getExtraComponents() {
        JButton buttonAddTrack = ComponentFactory.getButton(Resources.getText(DCLabels.lblAddTrack));
        buttonAddTrack.addActionListener(new AddTrackAcionListener());
        return new JComponent[] {buttonAddTrack};
    }
    
    /**
     * Adds a track (child) to the selected audio CD (parent) 
     */
    private class AddTrackAcionListener implements ActionListener {
        public void actionPerformed(ActionEvent arg0) {
            if (getParentID() != null && !getParentID().equals("")) {
                LinkedList row = new LinkedList();
                DCObject dco = getModule().getDataCrowObject();
                dco.setValue(dco.getParentReferenceFieldIndex(), getParentID());
                row.add(dco);
                addRow(row, false);
                
                int rowNumber = table.getRowCount() -1;
                dco.setUIRowNumber(rowNumber);
                llTracks.add(dco);
            } else {
                new MessageBox("Not allowed, add / select an album first !", 
                               MessageBox._ERROR);
            } 
        }
    }     
}
