/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.audiocd;

import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.util.Enumeration;
import java.util.LinkedList;
import java.util.Vector;

import javax.swing.JButton;
import javax.swing.JComponent;

import net.sf.dc.console.TableSearchPanel;
import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.dialogs.MessageBox;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.core.modules.DCModules;
import net.sf.dc.core.objects.DCObject;
import net.sf.dc.core.objects.Requestor;
import net.sf.dc.exceptions.ValidationException;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.ext.util.Resources;

/**
 * The insert Audio Track panel. This panel is different from the default panels
 * as this is a child panel of the Audio CD Panel. It also allows inserts of new
 * audio tracks
 * @see net.sf.dc.console.audiocd.SearchAudioCDPanel
 * 
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class SearchAudioTrackPanel extends TableSearchPanel {

    private Vector vNewTracks = new Vector(0);
    
    public SearchAudioTrackPanel() {
        super(DCModules.getModule(DCModules._AUDIOTRACK),
              Resources.getText(DCLabels.lblExistingValues), 
              IconLibrary._icoExisting);
    }
    
    public JComponent[] getExtraComponents() {
        JButton buttonAddTrack = ComponentFactory.getButton(Resources.getText(DCLabels.lblAddTrack));
        buttonAddTrack.addActionListener(new AddTrackAcionListener());
        return new JComponent[] {buttonAddTrack};
    }
    
    /**
     * Saves both the changes values as well as newly added tracks
     */
    public void saveChangedValues(boolean threaded) {
        saveNewValues(); 
    }
    
    /**
     * Indicates whether there are unsaved changes
     */
    public boolean changesSaved() {
        boolean saved = (table.noChanges()) && (vNewTracks.size() == 0); 
        return saved;
    }    
    
    /**
     * Indicates if a selected record is an existing or a new record
     */
    public boolean isNewlyAddedRow(int row) {
        boolean isNew = false;
        for (Enumeration enum = vNewTracks.elements(); enum.hasMoreElements(); ) {
            int i = ((Integer) enum.nextElement()).intValue();
            if (i == row) {
                isNew = true;
            }
        }
        return isNew;
    } 
    
    /**
     * Remove the rows from the table with the given indices
     * @param rows the indices of the to be removed rows
     */
    public void removeRows(int[] rows) {
        super.removeRows(rows);
        
        for (int i = 0; i < vNewTracks.size(); i++) {
            int row = ((Integer) vNewTracks.elementAt(i)).intValue();
            
            boolean smaller = true;
            for (int j = 0; j < rows.length; j++) {
            	if (rows[j] >= row) {
                    smaller = false;
                }
            }
            
            if (smaller) {
            	row = row - rows.length;
                vNewTracks.add(i, new Integer(row));
            }
        }
    }    
    
    /**
     * Clears the table and its cache
     */
    public void clearTable() {
    	super.clearTable();
        vNewTracks.clear();
    }
    
    /**
     * Clears the cache
     */
    public void clearCache() {
        table.clearCache();
        vNewTracks.clear();
    }    
    
    /**
     * Saves newly added track objects
     */
    public void saveNewValues() {
        int counter = 0;
        for (Enumeration enum = vNewTracks.elements(); enum.hasMoreElements(); counter++) {
        	int row = ((Integer) enum.nextElement()).intValue();
            DCObject o = table.getObjectForRow(row, true);
            o.addRequestor(new Requestor(getClass(), "clearCache", new Object[0]));
            o.setBatch(true);
            o.setValue(DCObject._ID, "");
            o.setUIRowNumber(row);
            o.setSilence(true);

            o.setEndOfBatch(counter == vNewTracks.size());
            try {
                o.saveNew();
            } catch (ValidationException vExp) {
                new MessageBox(vExp.getMessage(), MessageBox._WARNING);
                return;
            }
        }
        setStatus(Resources.getText(DCMessages.msgSaveHasBeenExecuted));        
    }  
    
    private class AddTrackAcionListener implements ActionListener {
        public void actionPerformed(ActionEvent arg0) {
            if (getParentID() != null && !getParentID().equals("")) {
            	LinkedList row = new LinkedList();
            	DCObject dco = getModule().getDataCrowObject();
            	dco.setValue(dco.getParentReferenceFieldIndex(), getParentID());
            	row.add(dco);
            	table.addRow(row, false);
                
                int rowNumber = table.getRowCount() -1;
                vNewTracks.addElement(new Integer(rowNumber));
                vNewTracks.trimToSize();
            } else {
            	new MessageBox("Not allowed, add / select an album first !", 
                               MessageBox._ERROR);
            }
        }
    }  
}
