/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components;

import java.awt.Color;
import java.awt.Component;

import javax.swing.JCheckBox;
import javax.swing.JComponent;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JLayeredPane;
import javax.swing.JPanel;
import javax.swing.JRootPane;
import javax.swing.JTabbedPane;

import net.sf.dc.core.Repository;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.SwingUtil;

/**
 * Super class for all frames within Data Crow.
 * It only handles setting the Frame as the root frame for modal messages.
 * 
 * @author Nuclear Vision
 * @since 1.4
 * @version 1.5
 */
public class DCFrame extends JFrame {

    public void setVisible(boolean visible) {
        super.setVisible(visible);
        
        setBackground(Settings.getValueAsColor(Repository.settings.stColor));
        
        if (visible) {
        	SwingUtil.setRootFrame(this);
        } 
    }
    
    public void setBackground(Color color) {
        super.setBackground(color);
        Component[] components = getComponents();
        for (int i = 0; i < components.length; i++) {
        	JComponent component = (JComponent) components[i];
            setBackground(component, color);
        }
    }        
    
    private void setBackground(JComponent component, Color color) {
    	if (component instanceof JLabel || component instanceof JPanel ||
            component instanceof JCheckBox || component instanceof JTabbedPane ||
            component instanceof JRootPane || component instanceof JLayeredPane) {
            
    		component.setBackground(color);
            
            Component[] components = component.getComponents();
            for (int i = 0; i < components.length; i++) {
                JComponent subComponent = (JComponent) components[i];
                setBackground(subComponent, color);
            }
        }
    }
}
