/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components;

import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.Insets;

/**
 * Used as the only reference for the Gridbag Layout to prevent multiple
 * instantations
 * 
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 1.00
 */
public final class Layout {
    
    private static final GridBagConstraints gbc = new GridBagConstraints();
    private static final GridBagLayout gbl = new GridBagLayout();
    
    public static GridBagLayout getGBL() {
        return gbl;
    }
    
    /**
     * Standard Swing translation...
     * 
     * @param x
     * @param y
     * @param width
     * @param height
     * @param xWeight
     * @param yWeigth
     * @param gbcAnchor
     * @param gbcStretch
     * @param insets
     * @param xPad
     * @param yPad
     * @return
     */
    public static GridBagConstraints getGBC (   int x,          
                                                int y,          
                                                int width,      
                                                int height,      
                                                double xWeight,
                                                double yWeigth,
                                                int gbcAnchor,
                                                int gbcStretch,
                                                Insets insets,
                                                int xPad,
                                                int yPad) {
        gbc.gridx = x;
        gbc.gridy = y;
        gbc.gridwidth = width;
        gbc.gridheight = height;
        gbc.weightx = xWeight;
        gbc.weighty = yWeigth;
        gbc.anchor = gbcAnchor;
        gbc.fill = gbcStretch;
        gbc.insets = insets;
        gbc.ipadx = xPad;
        gbc.ipady = yPad;
        return gbc;
    }
}
