/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components;

import java.awt.Toolkit;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;

import javax.swing.JTextArea;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.PlainDocument;

import net.sf.dc.console.dialogs.TextDialog;

/**
 * Field for showing and editing long text. A zoom function is
 * also implemented (@see net.sf.dc.console.TextView). The zoom
 * function is activated by a double click.
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.50
 */
public class LongTextField extends JTextArea {

    // the maximum length of the text
    private int MAX_TEXT_LENGTH = 0;
    private Toolkit toolkit;
    
    
    /**
     * Initializes this field
     * @param maxTextLength the maximum length of the text
     */
    public LongTextField(int maxTextLength) {
        super();
        
        addMouseListener(new TextWindowAction());
        
        MAX_TEXT_LENGTH = maxTextLength;
        toolkit = Toolkit.getDefaultToolkit();
    }


    protected Document createDefaultModel() {
        return new LongStringDocument();
    }

    public Object getValue() {
        return getText();
    }

    public void setValue(Object o) {
        setText(o.toString());
    }  

    /**
     * Implementation of a Document. This document makes sure that the
     * maximum text length is never exceeded by the user. A beep is 
     * played thru the speaker.
     */
    protected class LongStringDocument extends PlainDocument {
        public void insertString(int i, String s, AttributeSet attributeset)
            throws BadLocationException {

            if (i + 1 > MAX_TEXT_LENGTH) {
                toolkit.beep();
            } else {
                super.insertString(i, s, attributeset);
            }
        }
    }
    
    /**
     * Opens a text view (zoom function)
     * @see TextDialog
     */
    public void openTextWindow() {
        TextDialog textView = new TextDialog(getValue().toString());
        this.setText(textView.getText());
    }
    
    /**
     * Performs the zoom action (shows the text view)
     */
    public class TextWindowAction implements MouseListener {
        public void mouseReleased(MouseEvent e) {
            if (e.getClickCount() == 2) {
                openTextWindow();
            }
        }
        public void mouseEntered(MouseEvent e) {}
        public void mouseExited(MouseEvent e) {}
        public void mousePressed(MouseEvent e) {}
        public void mouseClicked(MouseEvent e) {}
    }    
}
