/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components.renderers;

import java.awt.Color;
import java.awt.Component;

import javax.swing.JButton;
import javax.swing.JTable;
import javax.swing.UIManager;
import javax.swing.border.Border;
import javax.swing.border.EtchedBorder;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.core.Repository;
import net.sf.ext.jflexsett.settings.Settings;

/**
 * Table renderer. Applies the right selection fore and background.
 * Enables the odd/even colors
 * 
 * @author Robert Jan van der Waals
 * @since 1.3
 * @version 1.00
 */
public class DCTableRowIndexCellRenderer extends DCTableCellRenderer {

    private final EtchedBorder border = new EtchedBorder(5);
    private final JButton button = ComponentFactory.getButton("");

    private static boolean disabled = false;
    private Border focusBorder = UIManager.getBorder("Table.focusCellHighlightBorder");
    
    public DCTableRowIndexCellRenderer() {}
    
    public Component getTableCellRendererComponent(
                                            JTable table, 
                                            Object value, 
                                            boolean isSelected, 
                                            boolean hasFocus, 
                                            int row,
                                            int column) {

        button.setText("" + (row + 1));
        button.setToolTipText("" + (row + 1));
        Color color = Settings.getValueAsColor(Repository.settings.stTableHeaderColor);
        button.setFont(ComponentFactory.getStandardFont());
        button.setBackground(color);
        button.setBorder(border);
        return button;
    }
}
