/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.components.renderers;

import java.awt.Component;
import java.util.Calendar;

import javax.swing.JComponent;
import javax.swing.JTable;

/**
 * Shows the time as "hh:mm:ss" within a table
 * 
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.5
 */
public class TimeFieldTableCellRenderer extends DCTableCellRenderer {
    
    private Calendar cal = Calendar.getInstance();
    
    public TimeFieldTableCellRenderer() {
        setOpaque(true);
        cal.set(Calendar.SECOND, 0);
        cal.set(Calendar.MINUTE, 0);
        setHorizontalAlignment(LEFT);
        setVerticalAlignment(CENTER);
    }
    
    public Component getTableCellRendererComponent( JTable table, 
                                                    Object value, 
                                                    boolean isSelected, 
                                                    boolean hasFocus, 
                                                    int row,
                                                    int column) {

    	    JComponent c = (JComponent) super.getTableCellRendererComponent(  
                            table,  
                            value,
                            isSelected,
                            hasFocus,
                            row,
                            column);
            
            //if (    Settings.getValueAsBoolean(Repository.settings.stShowTableTooltip) && 
              //      allowTooltips() && value != null) {
                String tooltipText = super.getText();
            	c.setToolTipText(tooltipText);
            //}
            return c;
    }
    
    
    public void setText(String str) {
        int minutes = 0;
        int seconds = 0;
        int hours = 0;
        
        if (cal == null) {
            cal = Calendar.getInstance();
        }
        
        cal.set(Calendar.SECOND, 0);
        cal.set(Calendar.MINUTE, 0);
        cal.set(Calendar.HOUR, 0);

        if (str != null && str.length() > 0) {
        	int value = Integer.parseInt(str);
        	cal.set(Calendar.SECOND, value);
        	minutes = cal.get(Calendar.MINUTE);
        	seconds = cal.get(Calendar.SECOND);
            hours = cal.get(Calendar.HOUR);
        }
        
        String sSeconds = getDoubleDigitString(seconds);
        String sMinutes = getDoubleDigitString(minutes);
        String text = "" + hours + ":" + sMinutes + ":" + sSeconds;
        super.setText(text);
    } 
    
    private String getDoubleDigitString(int value) {
        String s = "" + value;
        if (value == 0) {
            s = "00";
        } else if (s.length() == 1) {
            s = "0" + s;
        }
        return s;
    }
}
