/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.dialogs;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.Image;
import java.awt.Insets;

import javax.swing.JButton;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.JTextArea;
import javax.swing.ScrollPaneConstants;
import javax.swing.border.BevelBorder;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.DCFrame;
import net.sf.dc.console.components.Layout;
import net.sf.dc.core.IconLibrary;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.ext.util.Resources;
import net.sf.ext.util.Utilities;

/**
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.50
 */
public class AboutDialog extends DCFrame {
    
    private JButton buttonClose;

    /**
     * Initializes and creates this dialog, then it is shown
     */
    public AboutDialog() {
        buildDialog();
        
        setTitle(Resources.getText(DCLabels.lblAbout));
        setSize(new Dimension(350,350));
        Image img =IconLibrary._icoMain.getImage();
        setIconImage(img);
        img.flush();
        
        Dimension location = Utilities.getCenteredWindowLocation(getSize());
        setLocation(location.width, location.height);
    }

    /**
     * Closes and disposes this dialog
     */
    public void close() {
        this.dispose();
    }

    /**
     * Created this dialog
     */
    private void buildDialog() {
        //**********************************************************
        //Input panel
        //**********************************************************
        JPanel panelAbout = new JPanel(false);
        panelAbout.setLayout(Layout.getGBL());
        
        JTextArea textAbout = ComponentFactory.getTextArea();
        textAbout.setBackground(ComponentFactory.getTableColor());

        JScrollPane scroll = new JScrollPane(textAbout);
        scroll.setHorizontalScrollBarPolicy(ScrollPaneConstants.HORIZONTAL_SCROLLBAR_NEVER);
        scroll.setVerticalScrollBarPolicy(ScrollPaneConstants.VERTICAL_SCROLLBAR_NEVER);
        
        textAbout.setText("Data Crow was founded by Robert Jan van der Waals \n\r" +
                          "Original product: CD Library 3.03 \r\n" +
                          "\r\n" +
                          "The product is free for use and the source can be downloaded, " +
                          "edited and distributed under the GPL license terms \r\n" +
                          "\r\n" +
                          "Developers: \r\n" +
                          "Robert Jan van der Waals (rwaals@users.sourceforge.net) \r\n" +
                          "Jesper Kusk Christensen \r\n" +
                          "\r\n" +
                          "Contact: \r\n" +
                          "support@datacrow.net \r\n" + 
                          "http://sourceforge.net/projects/datacrow \r\n" +
                          "http://www.datacrow.net");
        textAbout.setEditable(false);
        
        scroll.setBorder(new BevelBorder(10));
        
        panelAbout.add(scroll, Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                               GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                               new Insets(5, 5, 5, 5), 0, 0));

        //**********************************************************
        //Main panel
        //**********************************************************        
        getContentPane().setLayout(Layout.getGBL());

        getContentPane().add(panelAbout,   Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                                           new Insets(5, 5, 5, 5), 0, 0));

        setTitle(Resources.getText(DCMessages.msgQuestion));
        pack();
    }
}
