/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.console.dialogs;

import java.awt.Dimension;
import java.awt.GridBagConstraints;
import java.awt.Insets;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;

import javax.swing.JButton;
import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.console.components.Layout;
import net.sf.dc.console.components.ShortTextField;
import net.sf.dc.core.Repository;
import net.sf.dc.messages.MessagesWriter;
import net.sf.dc.resources.DCLabels;
import net.sf.dc.resources.DCMessages;
import net.sf.ext.jflexsett.settings.Settings;
import net.sf.ext.util.Resources;
import net.sf.ext.util.Utilities;

/**
 * Login shows a small login window. The user needs to fill the database name and
 * select the driver used to communicate with this database (ms, sun or other).
 * An extra driver can be defined in the ini file
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.50
 */
public class LoginDialog extends JDialog {

    public static boolean done = false;

    private JLabel labelDriver;
    private JTextField textDriver;
    private JLabel labelDatabaseName;
    private ShortTextField textDatabaseName;

    private JButton buttonOK;
    private JButton buttonCancel;

    private JPanel panelInput = new JPanel(false);
    private JPanel panelActions = new JPanel(false);

    /**
     * Initializes and creates this dialog, then it is shown
     */
    public LoginDialog() {
        super(MessagesWriter.logForm);
        done = false;
        buildDialog();
        setDefaultCloseOperation(JDialog.DO_NOTHING_ON_CLOSE);
        this.setTitle(Resources.getText(DCLabels.lblConnection));

    	addWindowListener(new WindowAdapter() {
                public void windowClosing(WindowEvent e) {
                	System.exit(0);
                }
    	});

        this.setSize(new Dimension(350,150));
        
        Dimension location = Utilities.getCenteredWindowLocation(getSize());
        setLocation(location.width, location.height);
        
        buttonOK.requestFocus();
        this.setModal(true);
    }

    /**
     * Closes and disposes this dialog
     */
    public void close() {
        this.setModal(false);
        this.dispose();
    }

    /**
     * Verifies the selected database String and driver and saves them to the
     * Settings class
     */
    protected void verifyConnection() {
        String s = textDatabaseName.getText().trim();
        if (!s.equals("")) {
            Settings.setValue(Repository.settings.stConnectionString,
                              textDatabaseName.getText().trim());
        }

        done = true;
        close();
    }

    /**
     * Created this dialog
     */
    private void buildDialog() {
        //**********************************************************
        //Input panel
        //**********************************************************
        panelInput.setLayout(Layout.getGBL());

        labelDatabaseName = ComponentFactory.getLabel(Resources.getText(DCLabels.lblDatabaseName));
        textDatabaseName = ComponentFactory.getShortTextField(20);
        labelDriver = ComponentFactory.getLabel(Resources.getText(DCLabels.lblDatabaseDriver));
        textDriver = ComponentFactory.getShortTextField(20);

        textDatabaseName.setText(Settings.getValueAsString(Repository.settings.stConnectionString));
        textDriver.setText(Settings.getValueAsString(Repository.settings.stDatabaseDriver));

        panelInput.add(labelDriver,         Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                            new Insets(5, 5, 5, 5), 0, 0));
        panelInput.add(textDriver,          Layout.getGBC(1, 0, 1, 1, 1.0, 1.0,
                                            GridBagConstraints.NORTHEAST, GridBagConstraints.HORIZONTAL,
                                            new Insets(5, 5, 5, 5), 0, 0));
        panelInput.add(labelDatabaseName,   Layout.getGBC(0, 1, 2, 1, 1.0, 1.0,
                                            GridBagConstraints.NORTHWEST, GridBagConstraints.NONE,
                                            new Insets(5, 5, 5, 5), 0, 0));
        panelInput.add(textDatabaseName,    Layout.getGBC(1, 1, 1, 1, 1.0, 1.0,
                                            GridBagConstraints.NORTHEAST, GridBagConstraints.HORIZONTAL,
                                            new Insets(5, 5, 5, 5), 0, 0));

        //**********************************************************
        //Actions panel
        //**********************************************************        
        panelActions.setLayout(Layout.getGBL());
        
        buttonOK = ComponentFactory.getButton(Resources.getText(DCLabels.lblOK));
        buttonCancel = ComponentFactory.getButton(Resources.getText(DCLabels.lblCancel));
        buttonOK.addActionListener(new YesButtonAction());
        buttonCancel.addActionListener(new CancelButtonAction());

        panelActions.add(buttonOK,      Layout.getGBC(0, 0, 1, 1, 0.0, 0.0,
                                        GridBagConstraints.WEST, GridBagConstraints.NONE,
                                        new Insets(5, 5, 5, 5), 0, 0));
        panelActions.add(buttonCancel,  Layout.getGBC(1, 0, 1, 1, 0.0, 0.0,
                                        GridBagConstraints.WEST, GridBagConstraints.NONE,
                                        new Insets(5, 5, 5, 5), 0, 0));

        //**********************************************************
        //Main panel
        //**********************************************************        
        getContentPane().setLayout(Layout.getGBL());

        getContentPane().add(panelInput,   Layout.getGBC(0, 0, 1, 1, 1.0, 1.0,
                                           GridBagConstraints.NORTHWEST, GridBagConstraints.BOTH,
                                           new Insets(5, 5, 5, 5), 0, 0));
        getContentPane().add(panelActions, Layout.getGBC(0, 1, 1, 1, 1.0, 1.0,
                                           GridBagConstraints.SOUTHWEST, GridBagConstraints.NONE,
                                           new Insets(5, 5, 5, 5), 0, 0));

        setTitle(Resources.getText(DCMessages.msgQuestion));
        setResizable(true);
        pack();
    }


    private class YesButtonAction implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            verifyConnection();
        }
    }

    private class CancelButtonAction implements ActionListener {
        public void actionPerformed(ActionEvent e) {
            System.exit(0);
        }
    }
}
