/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.core.objects;

import java.net.URL;
import java.util.Calendar;

import net.sf.dc.console.components.ComponentFactory;
import net.sf.dc.core.Repository;
import net.sf.dc.core.objects.cache.CacheManager;
import net.sf.dc.messages.Messages;
import net.sf.ext.util.Converter;
import net.sf.ext.util.Utilities;

/**
 * Value definition for a Data Crow object
 * 
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 1.00
 */
public class DCValue {
    
    private Calendar cal = Calendar.getInstance();
    private boolean changed = false;
    private Object value = "";
    
    /**
     * Indicates whether the value has been changed
     */
    public boolean isChanged() {
        return changed;
    }
    
    /**
     * Mark a value as beign changed
     */
    public void setChanged(boolean b) {
        changed = b;
    }    
    
    /**
     * Applies a value
     * @param o the value to be applied
     * @param field the field definition to which this value belongs
     */
    public void setValue(Object o, DCFieldDefinition field) {
        setChanged(true);
        if (o == null) {
            o = "";
            return;
        } 
        
        if (field.getValueType() == Repository.datatypes._OBJECT) {
            try {
                value = o.toString();
                if (value.toString().endsWith("jpg")) {
                    URL url = new URL("file:/" + o.toString());
                    value = Utilities.fileToBase64String(url);
                } 
            } catch (Exception exp) {
            	Messages.setMessage(exp);   
            }
        } else if (field.getValueType() == Repository.datatypes._TYPEREFERENCE) {
            if (o instanceof DCObject) {
                value = o;
            } else {
                value = CacheManager.getObjectForID(o.toString());
            } 
            
            if (value == null) {
                value = CacheManager.getObjectForDisplayValue(o.toString());
            }
            
            if (value == null) {
                value = "";
            }
        } else if (field.getValueType() == Repository.datatypes._INTEGER) {
            try {
                if (o instanceof Integer) {
                    if (o.equals(new Integer(-1))) {
                        setChanged(false);
                    }
                    value = o;
                } else {
                    value = new Integer(Integer.parseInt(o.toString()));
                }
            } catch (Exception exp) {
                value = new Integer(0);
            } 
        } else {
            try {
                String s = Converter.databaseValueConverter(o.toString());
                if (    s.length() > field.getMaximumLength() && 
                        field.getMaximumLength() > 0) {
                    value = s.substring(0, field.getMaximumLength());
                } else {
                    value = s;
                }
            } catch (Exception exp) {
                value = "";
            }            
        }
    }
    
    /**
     * Returns the object value represented by the DCValue
     */
    public Object getValue() {
        return value; 
    }
    
    /**
     * Returns the value represented by the DCValue as a string
     */
    public String getValueAsString() {
        return value.toString();
    }
    
    public String getDisplayString(int fieldType) {
        Object o = getValue();
        String text = "";
        
        try {
            if (fieldType == ComponentFactory._TIMEFIELD) {
                cal.set(Calendar.SECOND, 0);
                cal.set(Calendar.MINUTE, 0);
                cal.set(Calendar.HOUR, 0);
                
                int value = 0;
                try {
                    value = Integer.parseInt(o.toString());
                } catch (Exception ignore) {}
        
                int minutes = 0;
                int seconds = 0;
                int hours = 0;
        
                if (value != 0) {
                    cal.set(Calendar.SECOND, value);
                    minutes = cal.get(Calendar.MINUTE);
                    seconds = cal.get(Calendar.SECOND);
                    hours = cal.get(Calendar.HOUR);
                }
                
                String sSeconds = getDoubleDigitString(seconds);
                String sMinutes = getDoubleDigitString(minutes);
                text = "" + hours + ":" + sMinutes + ":" + sSeconds;
            } else {
            	text = o.toString();
            }
        } catch (Exception ignore) {}
        
        return text;
    }    
    
    private String getDoubleDigitString(int value) {
        String s = "" + value;
        if (value == 0) {
            s = "00";
        } else if (s.length() == 1) {
            s = "0" + s;
        }
        return s;
    }      
}
