/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.core.objects;

/**
 * A request object. Here, the class name of the requestor for an action
 * is specified. The action itself consists out of the method and its
 * parameters. The MainFrame will execute the request
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.50
 */
public class Requestor {

    private Class       clazz;
    private String      sMethod;
    private Object[]    parameters;
    boolean bExecuteOnFail = false;

    /**
     * Creates a new requestor
     * @param clazz             the requestors class name
     * @param sMethod           method to be executed
     * @param parameters        the parameterd for the method
     * @param bExecuteOnFail    indicates if the action applies even if the query fails
     */
    public Requestor(Class clazz,
                     String sMethod, 
                     String[] parameters, 
                     boolean bExecuteOnFail) {
        this.clazz = clazz;
        this.sMethod = sMethod;
        this.parameters = parameters;
        this.bExecuteOnFail = bExecuteOnFail;
    }

    /**
     * Creates a new requestor
     * @param clazz             the requestors class name
     * @param sMethod           method to be executed
     * @param parameters        the parameterd for the method
     */
    public Requestor(Class clazz, String sMethod, Object[] parameters) {
        this.clazz = clazz;
        this.parameters = parameters;
        this.sMethod = sMethod;
    }

    /**
     * Returns the class name of the requestor
     */
    public Class getClazz() {
        return clazz;
    }

    /**
     * Returns the method name
     */
    public String getMethod() {
        return sMethod;
    }

    /**
     * Returns the parameters for the method
     */
    public Object[] getParameters() {
        return parameters;
    }

    /**
     * Indicates if the action applies even if the query fails
     */
    public boolean getExecuteOnFail() {
        return bExecuteOnFail;
    }
}
