/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.core.objects;

import java.util.LinkedList;

/**
 * Collection of Requestor Objects
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version DC0.50
 */
public class RequestorCollection {

    private LinkedList  requestorObjects    = new LinkedList();

    public RequestorCollection() {
    }
    
    /**
     * Initializes this Requestor Collection containing one Requestor
     * @param request to be added requestor
     */
    public RequestorCollection(Requestor request) {
        addRequestor(request);
    }

    /**
     * Adds a requestor to the list
     * @param requestor requestor to be added to the collection
     */
    public void addRequestor(Requestor requestor) {
        requestorObjects.add(requestor);
    }

    /**
     * Removes a requestor from the collection
     * @param requestor requestor to be removed
     */
    public void removeRequestor(Requestor requestor) {
        requestorObjects.remove(requestor);
    }

    /**
     * Creates a Requestor array from the collection
     */
    public Requestor[] toRequestorArray() {
        Object[] objects = requestorObjects.toArray();

        if (objects == null) {
            return null;
        }

        Requestor[] reqArray = new Requestor[objects.length];

        for (int i = 0; i < reqArray.length; i++) {
            reqArray[i] = (Requestor) objects[i];
        }

        return reqArray;
    }

    /**
     * Returns the amount of requestors in the collection
     */
    public int getLength() {
        return requestorObjects.size();
    }
}
