/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.core.objects.movie;

import javax.swing.ImageIcon;

import net.sf.dc.core.Repository;
import net.sf.dc.core.modules.DCModules;
import net.sf.dc.core.objects.DCFieldDefinition;
import net.sf.dc.core.objects.DCObject;
import net.sf.ext.jflexsett.settings.Settings;

/**
 * Movie object
 * 
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.50
 */
public class Movie extends DCObject {

    public static final int _A_TITLE = 1;
    public static final int _B_DESCRIPTION = 2;
    public static final int _C_WEBPAGE = 3;
    public static final int _D_GENRE = 4;
    public static final int _E_ACTORS = 5;
    public static final int _F_DIRECTOR = 6;
    public static final int _G_COUNTRY = 7;
    public static final int _H_YEAR = 8;
    public static final int _I_PLAYLENGTH = 9;
    public static final int _J_FILENAME = 10;
    public static final int _K_VIDEOCODEC = 11;
    public static final int _L_AUDIOCODEC = 12;
    public static final int _M_WIDTH = 13;
    public static final int _N_HEIGHT = 14;
    public static final int _O_FPS = 15;
    public static final int _P_FRAMES = 16;
    public static final int _Q_AUDIOBITRATE = 17;
    public static final int _R_AUDIOSAMPLINGRATE = 18;
    public static final int _S_AUDIOCHANNEL = 19;
    public static final int _T_VIDEOBITRATE = 20;
    public static final int _U_PICTUREFRONT = 21;
    public static final int _V_PICTUREBACK = 22;
    public static final int _W_PICTURECD = 23;
    public static final int _X_LOCATION = 24;

    public Movie() {
        super();
    }
    
    /**
     * Sets the module index / sets the ownership of this
     * data crow object  
     */    
    protected void setModuleIndex() {
        module = DCModules._MOVIE;
    }
    
    /**
     * Sets the database table name for this object 
     */    
    protected void setTableName() {
        sTableName = "Movie";
    }
    
    protected void setSelectTableDef() {
        sSelectTableDef = sTableName;
    }    
    
    /**
     * Returns the icon for this object
     */    
    public ImageIcon getIcon() {
        return null;    
    }
    
    /**
     * Initialize all user settings on this data crow object 
     */    
    protected void initializeSettings() {
        DCFieldDefinition[] fields = getFields();
        
        int[] requiredFields = Settings.getValueAsIntegerArray(
                                  Repository.settings.stMovieRequiredFields);
                                  
        for (int i = 0; i < requiredFields.length; i++) {
            fields[requiredFields[i]].setRequired(true);
        }
                                  
        int[] hiddenFields = Settings.getValueAsIntegerArray(
                                Repository.settings.stHiddenFieldsMovie);   

        for (int i = 0; i < hiddenFields.length; i++) {
            fields[hiddenFields[i]].setHidden(true);
        }
    }
    
    /**
     * Create a UI representation for this object
     */
    public String toString() {
        return getValue(Movie._A_TITLE).toString();
    }     
}
