/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.dc.db;

import java.util.Enumeration;
import java.util.Vector;

import net.sf.dc.core.objects.DCObject;

/**
 * This is the where part of the Query, it contains column names and their
 * values
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.50
 */
public class QueryCondition {

    private String[][] columns;
    private Vector vValues = new Vector();
    private String reference = "";
    public String linkContion = "";
    
    /**
     * Creates a query condition
     * @param parent parent data crow object
     * @param select indicates whether this is a select query or not
     */
    public QueryCondition(DCObject parent, boolean select) {
        Vector v = new Vector();
        v.addElement(parent);
        
        // In the case of children, create a condition for both parent and child
        // in one query
        DCObject[] children = parent.getChildren();
        if ((children != null && children.length > 0) && select) {
            int length = parent.getChangedFieldNames().length + children[0].
                          getChangedFieldNames().length;
            children[0].getChangedFieldNames();
        	columns = new String[length][2];
            v.addElement(children[0]);
        } else {
            columns = new String[parent.getChangedFieldNames().length][2];
        }
        
        for (Enumeration enum = v.elements(); enum.hasMoreElements(); ) {
        	DCObject obj = (DCObject) enum.nextElement();
        	Object[] values = obj.getChangedFieldValues();
        	Object[] fields = obj.getChangedFieldNames();
        
            if (values != null) {
                for (int i = 0; i < values.length; i++) {
                    Object value = values[i];
                    String column = fields[i].toString();
    
                    columns[i][0] = column;
                    columns[i][1] = obj.getTableName();
    
                    if (value instanceof String) {
                        vValues.add("'" + value + "'");
                        
                    } else if (value instanceof Integer) {
                        int integer = ((Integer) values[i]).intValue();
                        vValues.add(String.valueOf(integer));
                    } else if (value instanceof DCObject) {
                        vValues.add(((DCObject) value).getID());
                    } else {
                        vValues.add(value);
                    }
                }
            } else if (columns != null) {
                for (int i = 0; i < columns.length; i++) {
                    columns[i][0] = fields[i].toString();
                    columns[i][1] = obj.getTableName();
                }
            }
        }
    }
    
    /**
     * Returns the columns
     */
    public String[][] getColumns() {
        return columns;
    }

    /**
     * Returns the values
     */
    public Vector getValues() {
        return vValues;
    }
}
