package net.sf.ext.util;

import java.io.File;
import java.util.Vector;

import net.sf.dc.console.dialogs.QuestionBox;
import net.sf.dc.messages.Messages;
import net.sf.dc.resources.DCMessages;


/**
 * Reads all files from a specific location
 *
 * @author Robert-Jan van der Waals
 * @since 1.4
 * @version 1.0
 */
public class DirectoryReader {

    private static QuestionBox questionBox;

    /**
     * Retrieves all files and directories from the given locations
     *
     * @param sDrive starting location for reading data
     * @param bConfirmation ask for confirmation for eah directory
     * @param bLeveledSearch read subdirectories
     * @param bReturnDirectories allow directory names in the result
     * @param vExtensions extensions to filter on
     * @param logInformation write messages to the screen and the log
     */
    public static Vector read(String sDrive,
                              boolean bConfirmation,
							  boolean bLeveledSearch,
							  boolean bReturnDirectories,
							  String[] extensions,
							  boolean logInformation) throws Exception {

        Vector result = new Vector();
        File directory = new File(sDrive + File.separator);

        if (!directory.exists()) {
            return null;
        }

        boolean useFilter = false;
        if (extensions != null && extensions.length > 0) {
            useFilter = true;
        }

        Vector vUnhandeld = Converter.stringArrayToVector(directory.list());
        File tempFile = null;

        while (vUnhandeld.size() > 0) {
            String sCurrent = sDrive + File.separator + vUnhandeld.firstElement().toString();
            tempFile = new File(sCurrent);
            if (tempFile.isDirectory()) {
                if (bConfirmation) {
                    questionBox = new QuestionBox(Resources.getText(DCMessages.msgImport, sCurrent),
                                                  SwingUtil.getRootFrame());
                }
                
                if ((bConfirmation && QuestionBox.result.equals(Boolean.TRUE)) ||
                    !bConfirmation) {
                        
                    QuestionBox.result = null;
                    
                    if (logInformation) {
                    	Messages.setMessage(
                    			Resources.getText(DCMessages.msgReadingFrom, sCurrent), 
								Messages._STANDARD);
                    }

                    String[] list = tempFile.list();
                    if (list != null) {
                        for (int j = 0; j < list.length; j++) {
                            String sTempCurrent = sCurrent + File.separator + list[j];
                            if (!vUnhandeld.contains(sTempCurrent)) {
                                tempFile = new File(sTempCurrent);
                                if (tempFile.isDirectory()) {
                                    vUnhandeld.addElement(sTempCurrent.substring(sDrive.length() + 1, 
                                                                                 sTempCurrent.length()));
                                } else {
                                    if (useFilter && isValid(sTempCurrent, extensions)) {
                                        result.addElement(sTempCurrent);
                                    } else if (!useFilter) {
                                        result.addElement(sTempCurrent);
                                    }
                                }
                            }
                        }
                    }
                }  else {
                    QuestionBox.result = null;
                    
                    if (bReturnDirectories) {
                        if (logInformation) {
                            Messages.setMessage(
                                Resources.getText(DCMessages.msgRegDirName, sCurrent), 
                                Messages._STANDARD);
                        }
                        result.addElement(sCurrent);
                    }
                }
            } else {
                if (useFilter && isValid(sCurrent, extensions)) {
                    result.addElement(sCurrent);
                } else if (!useFilter) {
                    result.addElement(sCurrent);
                }
            }

            vUnhandeld.removeElementAt(0);

            if (!bLeveledSearch) {
                return result;
            }
        }
        result.trimToSize();
        return result;
    }

    private static boolean isValid(String filename, String[] extensions) {
        int last = filename.lastIndexOf(".");
        boolean valid = false;
        if (last + 1 < filename.length()) {
            filename = filename.substring(last + 1, filename.length());
            for (int i = 0; i < extensions.length; i++) {
                if (extensions[i].equals(filename.toLowerCase())) {
                	valid = true;
                	break;
                }
            }
        }
        return valid;
    }
}