/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   * 
 *                           sub-project: Utilites                            *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.ext.util;

import java.io.IOException;
import java.io.InputStream;

/**
 * Reads the disc id from an audio CD
 * 
 * @author Robert Jan van der Waals
 * @since 1.4
 * @version 1.5
 */
public class DiscIDReader {
    
    private boolean success = false;
    
    /**
     * Indicates whether the disc ID was read succesfully
     * @return success indicator
     */
    public boolean isSuccess() {
    	return success;
    }
    
    /**
     * Read the disc ID. The disc ID is read in a seperate process as this is
     * done platform dependend
     * @return valid disc id (with track offsets)
     * @throws IOException
     */
    public String readDiscID() throws IOException {
        Process p = null;
        String osName = System.getProperty("os.name");
        if (osName.startsWith("Mac OS")) {
            p = Runtime.getRuntime().exec("./discid/mac/discid.exe");
        } else if (osName.startsWith("Windows")) {
            p = Runtime.getRuntime().exec("./discid/win32/discid");
        } else {
            p = Runtime.getRuntime().exec("./discid/linux/discid");
        }    

        try {
        	p.waitFor();
        } catch (Exception exp) {}
        
        int exitvalue = p.exitValue();
        
        InputStream is = null;
        if (exitvalue == 1) {
            is = p.getErrorStream();
        } else {
            is = p.getInputStream();
            success = true;
        }

        byte[] b = new byte[is.available()];
    	is.read(b);
    	String s = new String(b);
        
        if (s.equals("")) {
        	success = false;
        }
        
        is.close();
        return s;
    }
}
