/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   * 
 *                           sub-project: Utilites                            *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.ext.util;

import java.io.File;

import net.sf.dc.resources.DCLabels;

/**
 * A file filter on file extensions
 * 
 * @author Robert Jan van der Waals
 * @version 1.0
 * @since 1.4
 */
public class FileFilter extends javax.swing.filechooser.FileFilter {
	
	private final String extension;
	
    /** 
     * Create a file filter for the give extensuib
     * @param extension criterium to filter
     */
	public FileFilter(String extension) {
		this.extension = extension;
	}
	
    /**
     * Check the file with the filter
     * @param file file to check on
     */
    public boolean accept(File file) {
        if (file.isDirectory()) {
            return true;
        } else if (Utilities.getExtension(file).equals(extension)) {
            return true;
        } else {
            return false;
        }
    }
    
    /**
     * Get the description of this filter for displaying purposes
     */
    public String getDescription() {
        return Resources.getText(DCLabels.lblFileFiler, extension);
    }
} 