/******************************************************************************
 *                                     __                                     *
 *                              <-----/@@\----->                              *
 *                             <-< <  \\//  > >->                             *
 *                               <-<-\ __ /->->                               *
 *                               Data /  \ Crow                               *
 *                                   ^    ^                                   *
 *                       (c) 2003 Robert-Jan van der Waals                    *
 *                             rwaals@anytimenow.com                          *
 *                                                                            *
 *                                                                            *
 *       This library is free software; you can redistribute it and/or        *
 *        modify it under the terms of the GNU Lesser General Public          *
 *       License as published by the Free Software Foundation; either         *
 *     version 2.1 of the License, or (at your option) any later version.     *
 *                                                                            *
 *      This library is distributed in the hope that it will be useful,       *
 *      but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU       *
 *           Lesser General Public License for more details.                  *
 *                                                                            *
 *     You should have received a copy of the GNU Lesser General Public       *
 *    License along with this library; if not, write to the Free Software     *
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA   *
 *                                                                            *
 ******************************************************************************/

package net.sf.ext.util;

import java.util.Hashtable;

/**
 * Holder of all resources
 *
 * @author Robert-Jan van der Waals
 * @since 1.3
 * @version 0.50
 */
public class Resources {
    private static Hashtable lblResModules;

    static {
    	try {
    	    lblResModules = new Hashtable();
    	} catch (Throwable t) {
    	    t.printStackTrace();
    	}
    }

    public static void addTextResourceBundle(ModularResourceBundle rb) {
    	String acronym = rb.getAcronym();

    	if(lblResModules.containsKey(acronym)) {
    	    throw new RuntimeException("Resource acronym already exists");
    	}

    	lblResModules.put(acronym, rb);
    }

    public static void removeTextResourceBundle(String acronym) {
    	if(!lblResModules.containsKey(acronym)) {
    	    throw new RuntimeException("Resource acronym does not exists");
    	}

    	lblResModules.remove(acronym);
    }

    public static boolean isTextResourceBundleRegistered(String acronym) {
    	return lblResModules.containsKey(acronym);
    }

    public static String getText(String id) {
    	return getText(id, (String[])null);
    }

    public static String getText(String id, String param1) {
    	return getText(id, new String[] {param1});
    }

    public static String getText(String id, String param1, String param2) {
    	return getText(id, new String[] {param1, param2});
    }

    public static String getText(String id, String param1, String param2, String param3) {
    	return getText(id, new String[] {param1, param2, param3});
    }

    public static String getText(String id, String[] params) {
    	String acronym = id.substring(0, 3);
    	ModularResourceBundle rs = (ModularResourceBundle)lblResModules.get(acronym);
    	String lbl =  rs.getString(id);
    	return params == null ? lbl : insertParams(lbl, params);
    }

    private static String insertParams(String s, String[] params) {
    	String result = s;
    	for (int i = 1; i - 1 < params.length; i++) {
    	    String searchPat = "%" + i;
    	    int index = 0;
    	    boolean escapedPatFound = false;
    
    	    do {
        		index = result.indexOf(searchPat, index);
        		if(index < 0) {
        		    throw new RuntimeException("Make sure we do not create recurive calls!!");
        		} else {
        		    escapedPatFound = (index > 0 &&
        			                   result.charAt(index - 1) == '\\');
        		}
    	    } while(escapedPatFound);
    	
            StringBuffer sb = new StringBuffer(result);
    	    sb.replace(index, index+searchPat.length(), params[i -1]);
    	    result = sb.toString();
    	}
    	return result;
    }
}
